<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>AboutDialog</name>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation type="unfinished">シンプルで使いやすいJabber / XMPPクライアント</translation>
    </message>
    <message>
        <source>License:</source>
        <translation type="unfinished">ライセンス:</translation>
    </message>
    <message>
        <source>Source code on GitHub</source>
        <translation type="obsolete">ソースコードは GitHub 上で公開</translation>
    </message>
    <message>
        <source>View source code online</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutSheet</name>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation type="vanished">シンプルで使いやすいJabber / XMPPクライアント</translation>
    </message>
    <message>
        <source>License:</source>
        <translation type="vanished">ライセンス:</translation>
    </message>
    <message>
        <source>Source code on GitHub</source>
        <translation type="vanished">ソースコードは GitHub 上で公開</translation>
    </message>
</context>
<context>
    <name>ChangePassword</name>
    <message>
        <source>Change password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New password (repeat):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New passwords do not match.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current password is invalid.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You need to be connected to change your password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>After changing your password, you will need to reenter it on all your other devices.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">キャンセル</translation>
    </message>
    <message>
        <source>Change</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChatMessage</name>
    <message>
        <source>Copy Message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quote</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChatPage</name>
    <message>
        <source>Compose message</source>
        <translation>メッセージを書く</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="vanished">送る</translation>
    </message>
    <message>
        <source>Select a file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send a spoiler message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spoiler hint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unmute notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mute notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View profile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CommonEncoderSettings</name>
    <message>
        <source>Very low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>High</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Very high</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Constant quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Constant bit rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Average bit rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Two pass</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadJob</name>
    <message>
        <source>Could not save file: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download failed: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EmojiPicker</name>
    <message>
        <source>Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>People</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Activity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Travel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Symbols</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search emoji</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EmptyChatPage</name>
    <message>
        <source>Please select a chat to start messaging</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <source>Select a file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileChooserMobile</name>
    <message>
        <source>Go to parent folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GlobalDrawer</name>
    <message>
        <source>Log out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invite friends</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invitation link copied to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Online</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Kaidan</name>
    <message>
        <source>The link will be opened after you have connected.</source>
        <extracomment>The link is an XMPP-URI (i.e. &apos;xmpp:kaidan@muc.kaidan.im?join&apos; for joining a chat)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No password found. Please enter it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No valid login QR code found.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginPage</name>
    <message>
        <source>Your Jabber-ID:</source>
        <translation type="vanished">君のJabber-ID：</translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation type="vanished">user＠example.jp</translation>
    </message>
    <message>
        <source>Your Password:</source>
        <translation type="vanished">君の合言葉：</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="vanished">合言葉</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>接続</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log in to your XMPP account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log in using a QR-Code</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaRecorder</name>
    <message>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaUtils</name>
    <message>
        <source>Take picture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record voice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose audio file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 (%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageHandler</name>
    <message>
        <source>Could not send message, as a result of not being connected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not correct message, as a result of not being connected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message correction was not successful.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MultimediaSettings</name>
    <message>
        <source>Multimedia Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Camera</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Container</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Codec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frame Rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ready</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Initializing...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recording...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NewMedia</name>
    <message>
        <source>Ready</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Initializing...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recording... %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paused %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QmlUtils</name>
    <message>
        <source>Available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Away</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid username or password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not resolve the server&apos;s address. Please check your server name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not connect to the server.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This server does not support registration.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An unknown error occured.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QrCodeScannerPage</name>
    <message>
        <source>Scan QR code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There is no camera available.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your camera is busy.
Try to close other applications using the camera.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The camera format &apos;%1&apos; is not supported.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RegistrationManager</name>
    <message>
        <source>Password changed successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to change password: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterAddContactSheet</name>
    <message>
        <source>user@example.org</source>
        <translation type="unfinished">user＠example.jp</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Add new contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This will also send a request to access the presence of the contact.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Jabber-ID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nickname:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Optional message:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tell your chat partner who you are.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterListItem</name>
    <message>
        <source>Error: Please check the JID.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterManager</name>
    <message>
        <source>Could not add contact, as a result of not being connected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not remove contact, as a result of not being connected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not rename contact, as a result of not being connected.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterPage</name>
    <message>
        <source>Contacts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add new contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search contacts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterRemoveContactSheet</name>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your roster?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete contact</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterRenameContactSheet</name>
    <message>
        <source>Rename contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">キャンセル</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SendMediaSheet</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">キャンセル</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished">送る</translation>
    </message>
    <message>
        <source>Caption</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Multimedia Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure photo, video and audio recording settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SubRequestAcceptSheet</name>
    <message>
        <source>Subscription Request</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You received a subscription request by &lt;b&gt;%1&lt;/b&gt;. If you accept it, the account will have access to your presence status.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Accept</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UploadManager</name>
    <message>
        <source>Could not send file, as a result of not being connected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserProfilePage</name>
    <message>
        <source>Profile</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VCardModel</name>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Email</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Birthday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Website</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
